==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Performance/src/com/clustercontrol/performance/composite/tree/CollectorRuleComposite.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.composite.tree;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import com.clustercontrol.bean.RunIntervalConstant;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
import com.clustercontrol.util.Messages;

/**
 * ƻ拾ݥåȥ饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class CollectorRuleComposite extends Composite {
	
	public static final int WIDTH_TITLE = 3;
	public static final int WIDTH_VALUE = 2;

    // ----- instance ե ----- //

    /** ¹Դֳ */
    private Combo m_comboRunInterval = null;


    // ----- 󥹥ȥ饯 ----- //

    /**
     * 󥹥󥹤֤ޤ
     * 
     * @param parent ƤΥݥå
     * @param style 
     */
    public CollectorRuleComposite(Composite parent, int style) {
        super(parent, style);
        
        this.initialize();
    }
    
    /**
     * ݥåȤۤޤ
     */
    private void initialize() {
    	
    	// ѿȤѤ٥
        Label label = null;
        // ѿȤѤ륰åɥǡ
        GridData gridData = null;
        
        GridLayout layout = new GridLayout(1, true);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
    	layout.numColumns = 15;	
        this.setLayout(layout);
        
        /*
         * ¹Դֳ֡ʬ
         */
        // ٥
        label = new Label(this, SWT.NONE);
        gridData = new GridData();
        gridData.horizontalSpan = WIDTH_TITLE;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        label.setLayoutData(gridData);
        label.setText(Messages.getString("collection.interval") + " : ");
        // ܥܥå
        this.m_comboRunInterval = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
        gridData = new GridData();
        gridData.horizontalSpan = WIDTH_VALUE;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        this.m_comboRunInterval.setLayoutData(gridData);
        
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_05);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_15);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_30);
        
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_01);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_05);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_15);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_30);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_60);
        
        // ͤȤ15ôֳ֤򡣤λ꤬ʤֻʤפ򤬲ǽȤʤäƤޤ
        this.m_comboRunInterval.select(1);
        
        // 
        label = new Label(this, SWT.NONE);
        gridData = new GridData();
        gridData.horizontalSpan = 8;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        label.setLayoutData(gridData);
	}

    /**
     * ƹܤͤꤷޤ
     * 
     * @param info ͤȤѤƻ
     */
	public void setInputData(RecordCollectorData info) {
		
		if(info != null){
            this.m_comboRunInterval.setText(RunIntervalConstant.typeToString(info.getInterval()));
		}
	}

	/**
     * ͤѤƴƻޤ
     * 
     * @return ڷ
     */
	public ValidateResult createInputData(RecordCollectorData info) {
		
		if(info != null){
	        if (this.m_comboRunInterval.getText() != null
	                && !"".equals((this.m_comboRunInterval.getText()).trim())) {
	        	info.setInterval(RunIntervalConstant.stringToType(this.m_comboRunInterval.getText()));
	        } else {
	        	return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.11"));
	        }
		}
		return null;
	}
	
	/* ( Javadoc)
	 * @see org.eclipse.swt.widgets.Control#setEnabled(boolean)
	 */
	@Override
	public void setEnabled(boolean enabled) {
		this.m_comboRunInterval.setEnabled(enabled);
	}
	
	/**
     * ̵ͤξꤷޤ
     *  
     */
    protected ValidateResult setValidateResult(String id, String message) {

    	ValidateResult validateResult = new ValidateResult();
        validateResult.setValid(false);
        validateResult.setID(id);
        validateResult.setMessage(message);
        
        return validateResult;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Performance/src/com/clustercontrol/performance/composite/tree/CollectorRuleComposite.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.composite.tree;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import com.clustercontrol.bean.RunIntervalConstant;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
import com.clustercontrol.util.Messages;

/**
 * 監視条件コンポジットクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class CollectorRuleComposite extends Composite {
	
	public static final int WIDTH_TITLE = 3;
	public static final int WIDTH_VALUE = 2;

    // ----- instance フィールド ----- //

    /** 実行間隔 */
    private Combo m_comboRunInterval = null;


    // ----- コンストラクタ ----- //

    /**
     * インスタンスを返します。
     * 
     * @param parent 親のコンポジット
     * @param style スタイル
     */
    public CollectorRuleComposite(Composite parent, int style) {
        super(parent, style);
        
        this.initialize();
    }
    
    /**
     * コンポジットを生成・構築します。
     */
    private void initialize() {
    	
    	// 変数として利用されるラベル
        Label label = null;
        // 変数として利用されるグリッドデータ
        GridData gridData = null;
        
        GridLayout layout = new GridLayout(1, true);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
    	layout.numColumns = 15;	
        this.setLayout(layout);
        
        /*
         * 実行間隔（分）
         */
        // ラベル
        label = new Label(this, SWT.NONE);
        gridData = new GridData();
        gridData.horizontalSpan = WIDTH_TITLE;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        label.setLayoutData(gridData);
        label.setText(Messages.getString("collection.interval") + " : ");
        // コンボボックス
        this.m_comboRunInterval = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
        gridData = new GridData();
        gridData.horizontalSpan = WIDTH_VALUE;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        this.m_comboRunInterval.setLayoutData(gridData);
        
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_05);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_15);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_SEC_30);
        
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_01);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_05);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_15);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_30);
        this.m_comboRunInterval.add(RunIntervalConstant.STRING_MIN_60);
        
        // 初期値として15秒間隔を選択。この指定がない場合「指定なし」の選択が可能となってしまう。
        this.m_comboRunInterval.select(1);
        
        // 空白
        label = new Label(this, SWT.NONE);
        gridData = new GridData();
        gridData.horizontalSpan = 8;
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        label.setLayoutData(gridData);
	}

    /**
     * 各項目に入力値を設定します。
     * 
     * @param info 設定値として用いる監視情報
     */
	public void setInputData(RecordCollectorData info) {
		
		if(info != null){
            this.m_comboRunInterval.setText(RunIntervalConstant.typeToString(info.getInterval()));
		}
	}

	/**
     * 入力値を用いて監視情報を生成します。
     * 
     * @return 検証結果
     */
	public ValidateResult createInputData(RecordCollectorData info) {
		
		if(info != null){
	        if (this.m_comboRunInterval.getText() != null
	                && !"".equals((this.m_comboRunInterval.getText()).trim())) {
	        	info.setInterval(RunIntervalConstant.stringToType(this.m_comboRunInterval.getText()));
	        } else {
	        	return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.11"));
	        }
		}
		return null;
	}
	
	/* (非 Javadoc)
	 * @see org.eclipse.swt.widgets.Control#setEnabled(boolean)
	 */
	@Override
	public void setEnabled(boolean enabled) {
		this.m_comboRunInterval.setEnabled(enabled);
	}
	
	/**
     * 無効な入力値の情報を設定します
     *  
     */
    protected ValidateResult setValidateResult(String id, String message) {

    	ValidateResult validateResult = new ValidateResult();
        validateResult.setValid(false);
        validateResult.setID(id);
        validateResult.setMessage(message);
        
        return validateResult;
    }
}
